@@ -1,4 +1,4 @@
-from .sorting import IsSorted
+from .sorting import IsSorted as __IsSorted
 
 # Searching algorithms
 
@@ -20,7 +20,7 @@ def BinarySearch(arr, item):
             Worst Case : O(1)
     """
 
-    if IsSorted(arr):
+    if __IsSorted(arr):
         if item in arr:
             start, end = 0, len(arr)-1
 
@@ -50,14 +50,14 @@ def ExponentialSearch(arr, item):
             Worst Case : O(1)
     """
 
-    if IsSorted(arr):
+    if __IsSorted(arr):
         n = len(arr)
 
         def binarySearch(arr, l, r, item):
             if item in arr:
                 while r >= l:
                     mid = l+(r-l)//2
-                    
+
                     if arr[mid] == item:
                         return mid
 
@@ -91,7 +91,7 @@ def FibonacciSearch(arr, item):
         Space Complexity :-
             Worst Case : O(1)
     """
-    
+
     if item in arr:
         m2, m1, n = 0, 1, len(arr)
         m = m2+m1
@@ -133,7 +133,7 @@ def InterpolationSearch(arr, item):
             Worst Case : O(1)
     """
 
-    if IsSorted(arr):
+    if __IsSorted(arr):
         if item in arr:
             start, end = 0, len(arr)-1
 
@@ -163,7 +163,7 @@ def JumpSearch(arr, item):
             Worst Case : O(1)
     """
 
-    if IsSorted(arr):
+    if __IsSorted(arr):
         n, prev = len(arr), 0
         step = n**0.5
 
@@ -184,7 +184,7 @@ def JumpSearch(arr, item):
 
         if arr[index] == item:
             return index
-        else:         
+        else:
             return False
     else:
         raise ValueError("Requires a sorted array; but got a random array")
@@ -206,4 +206,4 @@ def LinearSearch(arr, item):
             if arr[i] == item:
                 return i
     else:
-        return False
\ No newline at end of file
+        return False
